==> certmanager-model-v1alpha2-5.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VenafiTPPFluentImpl<A extends io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent<A>{
  public VenafiTPPFluentImpl() {
  }
  public VenafiTPPFluentImpl(io.fabric8.certmanager.api.model.v1alpha2.VenafiTPP instance) {
    this.withCaBundle(instance.getCaBundle()); 
    this.withCredentialsRef(instance.getCredentialsRef()); 
    this.withUrl(instance.getUrl()); 
  }
  private java.util.List<java.lang.Integer> caBundle;
  private io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder credentialsRef;
  private java.lang.String url;
  public A addToCaBundle(java.lang.Integer index,java.lang.Integer item) {
    if (this.caBundle == null) {this.caBundle = new java.util.ArrayList<java.lang.Integer>();}
    this.caBundle.add(index, item);
    return (A)this;
  }
  public A setToCaBundle(java.lang.Integer index,java.lang.Integer item) {
    if (this.caBundle == null) {this.caBundle = new java.util.ArrayList<java.lang.Integer>();}
    this.caBundle.set(index, item); return (A)this;
  }
  public A addToCaBundle(java.lang.Integer... items) {
    if (this.caBundle == null) {this.caBundle = new java.util.ArrayList<java.lang.Integer>();}
    for (java.lang.Integer item : items) {this.caBundle.add(item);} return (A)this;
  }
  public A addAllToCaBundle(java.util.Collection<java.lang.Integer> items) {
    if (this.caBundle == null) {this.caBundle = new java.util.ArrayList<java.lang.Integer>();}
    for (java.lang.Integer item : items) {this.caBundle.add(item);} return (A)this;
  }
  public A removeFromCaBundle(java.lang.Integer... items) {
    for (java.lang.Integer item : items) {if (this.caBundle!= null){ this.caBundle.remove(item);}} return (A)this;
  }
  public A removeAllFromCaBundle(java.util.Collection<java.lang.Integer> items) {
    for (java.lang.Integer item : items) {if (this.caBundle!= null){ this.caBundle.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.Integer> getCaBundle() {
    return this.caBundle;
  }
  public java.lang.Integer getCaBundle(java.lang.Integer index) {
    return this.caBundle.get(index);
  }
  public java.lang.Integer getFirstCaBundle() {
    return this.caBundle.get(0);
  }
  public java.lang.Integer getLastCaBundle() {
    return this.caBundle.get(caBundle.size() - 1);
  }
  public java.lang.Integer getMatchingCaBundle(java.util.function.Predicate<java.lang.Integer> predicate) {
    for (java.lang.Integer item: caBundle) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCaBundle(java.util.function.Predicate<java.lang.Integer> predicate) {
    for (java.lang.Integer item: caBundle) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCaBundle(java.util.List<java.lang.Integer> caBundle) {
    if (caBundle != null) {this.caBundle = new java.util.ArrayList<java.lang.Integer>(); for (java.lang.Integer item : caBundle){this.addToCaBundle(item);}} else { this.caBundle = null;} return (A) this;
  }
  public A withCaBundle(java.lang.Integer... caBundle) {
    if (this.caBundle != null) {this.caBundle.clear();}
    if (caBundle != null) {for (java.lang.Integer item :caBundle){ this.addToCaBundle(item);}} return (A) this;
  }
  public java.lang.Boolean hasCaBundle() {
    return caBundle != null && !caBundle.isEmpty();
  }
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference getCredentialsRef() {
    return this.credentialsRef!=null?this.credentialsRef.build():null;
  }
  public io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null?this.credentialsRef.build():null;
  }
  public A withCredentialsRef(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} return (A) this;
  }
  public java.lang.Boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  public A withNewCredentialsRef(java.lang.String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRef() {
    return new io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluentImpl.CredentialsRefNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRefLike(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
    return new io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluentImpl.CredentialsRefNestedImpl(item);
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef());
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder().build());
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRefLike(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VenafiTPPFluentImpl that = (VenafiTPPFluentImpl) o;
    if (caBundle != null ? !caBundle.equals(that.caBundle) :that.caBundle != null) return false;
    if (credentialsRef != null ? !credentialsRef.equals(that.credentialsRef) :that.credentialsRef != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  public class CredentialsRefNestedImpl<N> extends io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl<io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<N>> implements io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CredentialsRefNestedImpl(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
      this.builder = new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(this, item);
    }
    CredentialsRefNestedImpl() {
      this.builder = new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(this);
    }
    io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) VenafiTPPFluentImpl.this.withCredentialsRef(builder.build());
    }
    public N endCredentialsRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-5.12.4-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class VenafiTPPFluentImpl<A extends io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent<A>{
  public VenafiTPPFluentImpl() {
  }
  public VenafiTPPFluentImpl(io.fabric8.certmanager.api.model.v1alpha2.VenafiTPP instance) {
    this.withCaBundle(instance.getCaBundle()); 
    this.withCredentialsRef(instance.getCredentialsRef()); 
    this.withUrl(instance.getUrl()); 
  }
  private java.lang.String caBundle;
  private io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder credentialsRef;
  private java.lang.String url;
  public java.lang.String getCaBundle() {
    return this.caBundle;
  }
  public A withCaBundle(java.lang.String caBundle) {
    this.caBundle=caBundle; return (A) this;
  }
  public java.lang.Boolean hasCaBundle() {
    return this.caBundle != null;
  }
  
  /**
   * Method is deprecated. use withCaBundle instead.
   */
  @java.lang.Deprecated
  public A withNewCaBundle(java.lang.String arg0) {
    return (A)withCaBundle(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference getCredentialsRef() {
    return this.credentialsRef!=null?this.credentialsRef.build():null;
  }
  public io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference buildCredentialsRef() {
    return this.credentialsRef!=null?this.credentialsRef.build():null;
  }
  public A withCredentialsRef(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference credentialsRef) {
    _visitables.get("credentialsRef").remove(this.credentialsRef);
    if (credentialsRef!=null){ this.credentialsRef= new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(credentialsRef); _visitables.get("credentialsRef").add(this.credentialsRef);} return (A) this;
  }
  public java.lang.Boolean hasCredentialsRef() {
    return this.credentialsRef != null;
  }
  public A withNewCredentialsRef(java.lang.String name) {
    return (A)withCredentialsRef(new LocalObjectReference(name));
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRef() {
    return new io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluentImpl.CredentialsRefNestedImpl();
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRefLike(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
    return new io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluentImpl.CredentialsRefNestedImpl(item);
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef());
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRef() {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder().build());
  }
  public io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRefLike(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
    return withNewCredentialsRefLike(getCredentialsRef() != null ? getCredentialsRef(): item);
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VenafiTPPFluentImpl that = (VenafiTPPFluentImpl) o;
    if (caBundle != null ? !caBundle.equals(that.caBundle) :that.caBundle != null) return false;
    if (credentialsRef != null ? !credentialsRef.equals(that.credentialsRef) :that.credentialsRef != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(caBundle,  credentialsRef,  url,  super.hashCode());
  }
  public class CredentialsRefNestedImpl<N> extends io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluentImpl<io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<N>> implements io.fabric8.certmanager.api.model.v1alpha2.VenafiTPPFluent.CredentialsRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    CredentialsRefNestedImpl(io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference item) {
      this.builder = new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(this, item);
    }
    CredentialsRefNestedImpl() {
      this.builder = new io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder(this);
    }
    io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) VenafiTPPFluentImpl.this.withCredentialsRef(builder.build());
    }
    public N endCredentialsRef() {
      return and();
    }
    
  }
  
}
